--[[
Script to update existing brands.

Author:  Iceflower S
Version: 22.2022.1.29

History:
22.2022.1.29
    - initial release in FS 22

License:
Copyright 2022 Iceflower S

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

BrandsXT = {}

BrandsXT.name = "Brands XT"
BrandsXT.currentModDirectory = g_currentModDirectory
BrandsXT.debugMode = false

local function updateBrand(name, title, image, imageShopOverview, imageOffset)
    -- Check if empty or not.
    if name == nil or name == '' then
        print("  Error: (" .. BrandsXT.name .. ") Brand had no name! ('" .. name .. "' | '" .. title .. "' | '" .. image .. "')")
        return
    end
    -- Update only existing brands.
    local brandIdx = g_brandManager:getBrandIndexByName(name)
    if brandIdx == nil then
        print("  Error: (" .. BrandsXT.name .. ") Brand had no index! ('" .. name .. "'")
        return
    end

    print("  Info: (" .. BrandsXT.name .. ") Updating brand '" .. name .. "'")
    -- Update title.
    if title ~= nil then
        -- Get translations.
        if title:sub(1, 6) == "$l10n_" then
            title = g_i18n:getText(title:sub(7))
        end

        g_brandManager.nameToBrand[name].title = title
        g_brandManager.indexToBrand[brandIdx].title = title
    end
    -- Update image and imageShopOverview.
    if image ~= nil then
        local imageFile = ""
        if string.sub(image, 1, 1) == "$" then
            imageFile = string.sub(image, 2)
        else
            imageFile = Utils.getFilename(image, BrandsXT.currentModDirectory)
        end
        if not fileExists(imageFile) then
            print("  Error: (" .. BrandsXT.name .. ") image does not exist! (" .. name .. "): '" .. imageFile .. "'")
            return
        end

        g_brandManager.nameToBrand[name].image = imageFile
        g_brandManager.indexToBrand[brandIdx].image = imageFile
    end
    -- Update imageShopOverview.
    if image ~= nil and imageShopOverview == nil then
        imageShopOverview = image
    end
    if imageShopOverview ~= nil then
        local imageShopOverviewFile = ""
        if string.sub(imageShopOverview, 1, 1) == "$" then
            imageShopOverviewFile = string.sub(imageShopOverview, 2)
        else
            imageShopOverviewFile = Utils.getFilename(imageShopOverview, BrandsXT.currentModDirectory)
        end
        if not fileExists(imageShopOverviewFile) then
            print("  Error: (" .. BrandsXT.name .. ") imageShopOverview does not exist! (" .. name .. "): '" .. imageShopOverviewFile .. "'")
            return
        end

        g_brandManager.nameToBrand[name].imageShopOverview = imageShopOverviewFile
        g_brandManager.indexToBrand[brandIdx].imageShopOverview = imageShopOverviewFile
    end
    -- Update imageOffset.
    if imageOffset ~= nil then
        g_brandManager.nameToBrand[name].imageOffset = imageOffset
        g_brandManager.indexToBrand[brandIdx].imageOffset = imageOffset
    end
end

local function updateBrands()
    local modDesc = loadXMLFile("modDesc", BrandsXT.currentModDirectory .. "modDesc.xml")

    local curBrandIdx = 0
    while true do
        local baseXMLName = string.format("modDesc.brands.brand(%d)", curBrandIdx)

        if not hasXMLProperty(modDesc, baseXMLName) then
            break
        end
        local name = getXMLString(modDesc, baseXMLName .. "#name")
        local title = getXMLString(modDesc, baseXMLName .. "#title")
        local image = getXMLString(modDesc, baseXMLName .. "#image")
        local imageShopOverview = getXMLString(modDesc, baseXMLName .. "#imageShopOverview")
        local imageOffset = getXMLFloat(modDesc, baseXMLName .. "#imageOffset")

        updateBrand(name:upper(), title, image, imageShopOverview, imageOffset)

        curBrandIdx = curBrandIdx + 1
    end

    delete(modDesc)
end

Vehicle.init = Utils.prependedFunction(Vehicle.init, updateBrands);
